@@ -3,8 +3,9 @@ use v5.10;
 use Dancer ':syntax';
 use Dancer::Plugin;
 use Scalar::Util 'blessed';
+use Time::HiRes 'time';
 
-our $VERSION = '1.08';
+our $VERSION = '1.09';
 
 no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
@@ -71,7 +72,6 @@ register PLUGIN_NAME ,=> sub {
         my @responses;
         for my $request (@requests) {
             my $method_name = $request->{method};
-            debug("[handle_jsonrpc_call($method_name)] $method_name ", $request);
 
             if (!exists $dispatcher->{$method_name}) {
                 push(
@@ -88,6 +88,9 @@ register PLUGIN_NAME ,=> sub {
             }
 
             my $method_args = $request->{params};
+
+            my $start_request = time();
+            debug("[handle_jsonrpc_call($method_name)] ", $method_args);
             my Dancer::RPCPlugin::CallbackResult $continue = eval {
                 local $Dancer::RPCPlugin::ROUTE_INFO = {
                     plugin        => PLUGIN_NAME,
@@ -144,7 +147,11 @@ register PLUGIN_NAME ,=> sub {
             };
             my $error = $@;
 
-            debug("[handled_jsonrpc_call($method_name)] ", flatten_data($result));
+            debug("[handled_jsonrpc_request($method_name)] ", flatten_data($result));
+            info( sprintf(
+                "[RPC::JSONRPC] request for %s took %.4fs",
+                $method_name, time() - $start_request
+            ));
             if ($error) {
                 my $error_response = blessed($error) && $error->can('as_jsonrpc_error')
                     ? $error
@@ -186,6 +193,7 @@ register PLUGIN_NAME ,=> sub {
             $response = to_json([grep {defined($_->{id})} @responses], $jsonise_options);
         }
 
+        debug("[jsonrpc_response] ", $response);
         return $response;
     };
 
