@@ -3,8 +3,9 @@ use v5.10;
 use Dancer ':syntax';
 use Dancer::Plugin;
 use Scalar::Util 'blessed';
+use Time::HiRes 'time';
 
-our $VERSION = '1.08';
+our $VERSION = '1.09';
 
 no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
@@ -75,6 +76,9 @@ register PLUGIN_NAME ,=> sub {
         my $method_args = request->body
             ? from_json(request->body)
             : undef;
+
+        debug("[handle_restrpc_call($method_name)] ", $method_args);
+        my $start_request = time();
         my Dancer::RPCPlugin::CallbackResult $continue = eval {
             local $Dancer::RPCPlugin::ROUTE_INFO = {
                 plugin        => PLUGIN_NAME,
@@ -121,7 +125,7 @@ register PLUGIN_NAME ,=> sub {
                 $code_wrapper->($handler, $package, $method_name, $method_args);
             };
 
-            debug("[handling_jsonrpc_response($method_name)] ", $response);
+            debug("[handled_restrpc_request($method_name)] ", flatten_data($response));
             if (my $error = $@) {
                 my $error_response = blessed($error) && $error->can('as_restrpc_error')
                     ? $error
@@ -145,6 +149,10 @@ register PLUGIN_NAME ,=> sub {
         if (config->{encoding} && config->{encoding} =~ m{^utf-?8$}i) {
             $jsonise_options->{utf8} = 1;
         }
+        info( sprintf(
+            "[RPC::RESTRPC] request for %s took %.4fs",
+            $method_name, time() - $start_request
+        ));
         return to_json($response, $jsonise_options);
     };
 
